# pinster

Hitster CLI clone. Guess the song name, artist and year just by listening.

## Requirements for playing

You need a Spotify Developer App configured
(https://developer.spotify.com/documentation/web-api/tutorials/getting-started).

## Instructions

Simply install and/or run the command using your preferred package manager
(example: `uvx pinster`). Use the `--help` option if needed.

The game plays a random song from your Liked Songs. Pause using `Enter` and guess
the song details. Press `Enter` to reveal the answer. Press `Enter` again to play
the next song.
